import Layout from '@/layout'

const businessRouter = {
  path: '/business',
  component: Layout,
  name: 'Business',
  meta: { title: '业务中心', icon: 'el-icon-s-shop' },
  redirect: 'noRedirect',
  children: [
    {
      path: 'outlet',
      component: () => import('@/views/business/outlet/index'),
      name: 'BusinessOutlet',
      meta: { title: '门店管理', icon: 'el-icon-s-shop' },
      redirect: '/business/outlet/list',
      children: [
        {
          path: 'list',
          component: () => import('@/views/business/outlet/list/index'),
          name: 'BusinessOutletList',
          meta: { title: '门店列表' }
        },
        {
          hidden: true,
          path: 'detail',
          component: () => import('@/views/business/outlet/detail/index'),
          name: 'BusinessOutletDetail',
          meta: { title: '门店详情', noCache: true },
          props: (route) => ({
            id: route.query.id
          })
        }
      ]
    },
    {
      path: 'place',
      component: () => import('@/views/business/place/index'),
      name: 'BusinessPlace',
      meta: { title: '订座管理', icon: 'el-icon-place' },
      redirect: '/business/place/query',
      children: [
        {
          path: 'list',
          component: () => import('@/views/business/place/list/index'),
          name: 'BusinessPlaceList',
          meta: { title: '座位管理' }
        },
        {
          path: 'query',
          component: () => import('@/views/business/place/query/index'),
          name: 'BusinessPlaceQuery',
          meta: { title: '预定查询' }
        },
        {
          path: 'release',
          component: () => import('@/views/business/place/release/index'),
          name: 'BusinessPlaceRelease',
          meta: { title: '订座安排' }
        }
      ]
    },
    {
      path: 'show',
      component: () => import('@/views/business/show/index'),
      name: 'BusinessShow',
      meta: { title: '演出管理', icon: 'el-icon-headset' },
      redirect: '/business/show/music',
      children: [
        {
          path: 'music',
          component: () => import('@/views/business/show/music/index'),
          name: 'BusinessShowMusic',
          meta: { title: '点歌记录' }
        },
        {
          path: 'plan',
          component: () => import('@/views/business/show/plan/index'),
          name: 'BusinessShowPlan',
          meta: { title: '演出安排' }
        },
        {
          path: 'artList',
          component: () => import('@/views/business/show/artList/index'),
          name: 'BusinessShowArtList',
          meta: { title: '艺人管理' }
        }
      ]
    },
    {
      path: 'order',
      component: () => import('@/views/business/order/index'),
      name: 'BusinessOrder',
      meta: { title: '点单管理', icon: 'el-icon-s-order' },
      redirect: '/business/order/list',
      children: [
        {
          path: 'list',
          component: () => import('@/views/business/order/list/index'),
          name: 'BusinessOrderList',
          meta: { title: '订单列表' }
        },
        {
          path: 'goods',
          component: () => import('@/views/business/order/goods/index'),
          name: 'BusinessOrderGoods',
          meta: { title: '橱窗管理' }
        }
      ]
    }
  ]
}

export default businessRouter
